@@ -19,9 +19,9 @@ import sys
 import os
 from os import path
 
-from calculate.core.datavars import DataVars
-from calculate.core.server.core_interfaces import MethodsInterface
-from calculate.core.server.gen_pid import get_pid_info, ProcessMode
+from .datavars import DataVars
+from .server.core_interfaces import MethodsInterface
+from .server.gen_pid import get_pid_info, ProcessMode
 from calculate.lib.datavars import Variable
 from calculate.lib.cl_log import log
 from calculate.lib.utils.common import getPasswdUsers
@@ -129,10 +129,9 @@ class UpdateConfigs(UpdateLogger):
         """
         user, dn = 0, 1
         iniEnv = ".calculate/ini.env"
-        return map(lambda x: x[user],
-                   filter(lambda x: path.exists(path.join(x[dn], iniEnv)),
-                          map(lambda x: (x, pwd.getpwnam(x).pw_dir),
-                              getPasswdUsers())))
+        return [x[user] for x in [(y, pwd.getpwnam(y).pw_dir) for y 
+            in getPasswdUsers()] if path.exists(path.join(x[dn], iniEnv))]
+        
 
     def _setClMergePkg(self, clVars, category, nameProgram, slot=None):
         """
@@ -142,11 +141,9 @@ class UpdateConfigs(UpdateLogger):
         # выбрана перенастройка всех пакетов, установленных в системе
         if nameProgram == "all":
             clVars.Set("cl_merge_pkg",
-                       map(lambda x: "{CATEGORY}/{PN}".format(**x),
-                           filter(None,
-                                  map(reVerSplitToPV,
-                                      glob.glob('/var/db/pkg/*/*')))),
-                       True)
+                    ["{CATEGORY}/{PN}".format(**x) for x 
+                        in map(reVerSplitToPV, glob.glob('/var/db/pkg/*/*')) if x],
+                    True)
         else:
             if slot:
                 clVars.Set("cl_merge_pkg", ["%s/%s:%s" % (category,
@@ -165,8 +162,7 @@ class UpdateConfigs(UpdateLogger):
         """
         # настраиватся будут пользователи из активных X сессии
         # и сконфигурированные
-        xUsers = filter(lambda x: not "(unknown)" in x,
-                        self.getXUsers())
+        xUsers = [x for x in self.getXUsers() if not "(unknown)" in x]
         if not xUsers:
             self.logger.info(_("Package %s") % nameProgram)
             self.logger.warn(_("X session users not found"))
@@ -319,7 +315,7 @@ class UpdateConfigs(UpdateLogger):
         """
         Проверить наличие запущенных процессов в cl-core
         """
-        from calculate.core.server.loaded_methods import LoadedMethods
+        from .server.loaded_methods import LoadedMethods
 
         cur_pid = os.getpid()
         pid_list = [pid for pid in get_pid_info(self.clVars)
@@ -354,3 +350,61 @@ class UpdateConfigs(UpdateLogger):
         time.sleep(1)
         os.system('/etc/init.d/%s restart &>/dev/null &' % service_name)
         return True
+
+    def processConfig(self, nameProgram, version, slot, category,
+                      verbose, dispatchConf, templates_locate,
+                      ebuildPhase, useClt, arch_machine):
+        """
+        Обновить конфигурационные файлы системы
+        """
+        self.logger.info(_("Package %s") % nameProgram)
+        self.logger.info(_("Updating system cofiguration files"))
+
+        clVars = DataVars()
+        try:
+            clVars.importData()
+            clVars.flIniFile()
+            clVars.Set("cl_root_path", "/", True)
+
+            if self.clVars.Get('core.cl_core_pkg_slot_opt') != "all":
+                self._setClMergePkg(clVars, category, nameProgram, slot)
+            else:
+                self._setClMergePkg(clVars, category, nameProgram)
+            clVars.Set("cl_action", 'config', True)
+            clVars.Set("cl_verbose_set", verbose, True)
+            clVars.Set("cl_dispatch_conf", dispatchConf, True)
+            clVars.Set("cl_template_path_use", templates_locate, True)
+            clVars.Set("core.cl_core_pkg_slot", slot, True)
+            useClt = False
+
+            #dictVer = {slot: version}
+            #cl_template.templateFunction.installProg.update(
+            #    {"%s/%s" % (category, nameProgram): dictVer,
+            #     "%s" % nameProgram: dictVer})
+
+            # используем объект шаблонов
+            # с clt шаблонами, clt фильтром, без использования postDispatchConf
+            clTempl = ChainProgressTemplate(
+                self.startTask,
+                self.endTask,
+                self.setProgress,
+                clVars, cltObj=useClt,
+                cltFilter=True,
+                printSUCCESS=self.printSUCCESS,
+                printERROR=self.printERROR,
+                printWARNING=self.printWARNING,
+                askConfirm=self.askConfirm,
+                dispatchConf=self.dispatchConf
+                if not ebuildPhase and self.isInteractive() else None,
+                printWarning=False)
+            # выводим сообщение о настройке пакета только если действительно
+            # менялись файлы
+            clTempl.onFirstValue = lambda *args: \
+                self.startTask(_("System configuring for {nameProgram} "
+                                 "package by Calculate Utilities").format(
+                    nameProgram=nameProgram))
+            clTempl.applyTemplates()
+        finally:
+            clVars.close()
+            self.endTask()
+        return True
