@@ -269,8 +269,12 @@ class VariableClCorePkgCategory(Variable):
             return []
         pkgname = self.Get('cl_core_pkg_name')
         if pkgname not in self.pkgCategories:
-            self.pkgCategories[pkgname] = \
-                glob.glob('/usr/portage/*/%s' % pkgname)
+            if os.path.isdir('/var/db/repos/gentoo'):
+                self.pkgCategories[pkgname] = \
+                    glob.glob('/var/calculate/*/%s' % pkgname)
+            else:
+                self.pkgCategories[pkgname] = \
+                    glob.glob('/usr/portage/*/%s' % pkgname)
         return [path.split(path.split(x)[0])[1] for x 
             in self.pkgCategories[pkgname]]
 
